# Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Syntax is:
#   conf_device $ID $NATIVE_TCT_REPO
#   copy_ssh $IP $FILE
#   copy_sdb $ID $FILE
#
# conf_device runs install script from Native TCT repository and copies files
# required by TCT in order to properly test the image on a target device.
#
# Author: Aleksander Mistewicz <a.mistewicz@samsung.com>

conf_device() {
    ID="$1"
    NATIVE_TCT_REPO="$2"
    test -n "${ID}" || die "Missing argument: id"
    test -n "${NATIVE_TCT_REPO}" || die "Missing argument: native_tct_repo"
    test -n "${TESTLAB_SCRIPTS}" || die "Missing env: testlab_scripts"

    NATIVE_TCT_TOOLS="${NATIVE_TCT_REPO}/tool/native-tct-3.0/tools"
    cd "${NATIVE_TCT_TOOLS}" || die "cd to ${NATIVE_TCT_TOOLS} failed"
    python ./tct-config-device.py "--deviceid=${ID}"
    cd "${OLDPWD}"

    APP_DIR="/home/owner/content/Documents/tct"

    SUFFIX=''
    if [ ! -f "${TESTLAB_SCRIPTS}/conf/capability.xml" ]
    then
        SUFFIX='.example'
    fi
    sdb -s "${ID}" push "${TESTLAB_SCRIPTS}/conf/capability.xml$SUFFIX" \
        "${APP_DIR}/capability.xml"

    SUFFIX=''
    if [ ! -f "${TESTLAB_SCRIPTS}/conf/buildinfo.xml" ]
    then
        SUFFIX='.example'
    fi
    sdb -s "${ID}" push "${TESTLAB_SCRIPTS}/conf/buildinfo.xml$SUFFIX" \
        "${APP_DIR}/buildinfo.xml"

    sdb -s "${ID}" push "${TESTLAB_SCRIPTS}/conf/configure_env.sh" /etc/profile.d/
}

copy_ssh() {
    IP="$1"
    FILE="$2"
    test -n "${IP}" || die "Missing argument: ip"
    test -n "${FILE}" || die "Missing argument: file"
    COUNT=1
    while ! timeout 60 sshpass -p 'tizen' scp -F "${TESTLAB_SCRIPTS}/conf/ssh_config" \
        "${FILE}" "root@${IP}:/tmp/smoke.sh"
    do
        echo "SSH connection to ${IP} failed: retrying" >&2
        if [ ${COUNT} -ge 6 ]
        then
            die "Timeout: ssh connection failed!"
        fi
        COUNT=$((COUNT+1))
    done
}

copy_sdb() {
    ID="$1"
    FILE="$2"
    test -n "${ID}" || die "Missing argument: id"
    test -n "${FILE}" || die "Missing argument: file"
    sdb -s "${ID}" push "${FILE}" "/tmp/smoke.sh" || die "SDB copy failed!"
}
