#!/bin/sh

# Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Script used to flash, prepare and configure ODROID U3
#
# Syntax is: odroid_prepare_conf_flash.sh $SDMUX $BOOT_IMAGE $IMAGE \
#    [$NATIVE_TCT_REPO]
#
# Author: Aleksander Mistewicz <a.mistewicz@samsung.com>

export TESTLAB_SCRIPTS="$(CDPATH='' cd -- "$(dirname -- "$0")" && pwd -P)"

. "${TESTLAB_SCRIPTS}/common.sh"

SDMUX="$1"
BOOT_IMAGE="$2"
IMAGE="$3"
NATIVE_TCT_REPO="$4"

test -n "${SDMUX}" || die "Missing argument: sdmux!"
test -n "${BOOT_IMAGE}" || die "Missing argument: boot image!"
test -n "${IMAGE}" || die "Missing argument: image!"

. "${TESTLAB_SCRIPTS}/prepare/prepare.sh"
. "${TESTLAB_SCRIPTS}/flash/flash.sh"
. "${TESTLAB_SCRIPTS}/conf/conf.sh"
. "${TESTLAB_SCRIPTS}/run/run.sh"

echo "### prepare ###"

IMAGE_UNPACKED="/tmp/image_unpacked_${SDMUX}"
IMAGE_MOUNTPOINT="/tmp/image_mounted_${SDMUX}"

switch2testserver "${SDMUX}"

unpack_image "${BOOT_IMAGE}" "${IMAGE}" "${IMAGE_UNPACKED}"

mount_image "${IMAGE_UNPACKED}/rootfs.img" "${IMAGE_MOUNTPOINT}"
install_iserial "${SDMUX}" "${IMAGE_MOUNTPOINT}"
unmount_image "${IMAGE_MOUNTPOINT}"

echo "### flash ###"

UUID_FILE="/var/tmp/uuid-${SDMUX}"
DEV_SDCARD=$(uuid2dev "${UUID_FILE}" "${SDMUX}")

cd "${IMAGE_UNPACKED}"
"${TESTLAB_SCRIPTS}/flash/flash_dd.sh" "${DEV_SDCARD}"
RET=$?
cd "${OLDPWD}"

change_uuid "${UUID_FILE}" "${DEV_SDCARD}"
if [ $RET -ne 0 ]; then
    die "flash_dd exited with an error" "$RET"
fi
switch2device "${SDMUX}"
restart_device "${SDMUX}"

echo "### conf ###"

CONNECT_CNT=0
sdb start-server
SLEEP=10

while [ -z "$(sdb devices | awk -v SDMUX="${SDMUX}" '$1 == SDMUX {print $1}')" ]
do
    printf "."
    if [ ${SLEEP} -ge 120 ]
    then
        die "Timeout: sdb device not found!" >&2
    fi
    if [ ${SLEEP} -ge 60 ]
    then
        echo "Restarting ODROID" >&2
        restart_device "${SDMUX}"
    fi
    sleep "${SLEEP}"
    SLEEP=$((SLEEP+10))
    CONNECT_CNT=$((CONNECT_CNT+1))
done

printf "\n"
sleep 4

if [ -n "${NATIVE_TCT_REPO}" ]
then
    conf_device "${SDMUX}" "${NATIVE_TCT_REPO}"
else
    sdb -s "${SDMUX}" root on
fi

copy_sdb "${SDMUX}" "${TESTLAB_SCRIPTS}/run/smoke_tests.sh"
run_smoke_sdb "${SDMUX}"

echo "CONNECT_CNT $CONNECT_CNT" >> sysctl.result
cat sysctl.result

echo "### cleanup ###"

switch2testserver "${SDMUX}"

rm -rf "${IMAGE_MOUNTPOINT}"
rm -rf "${IMAGE_UNPACKED}"
