# Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# This function takes up to two arguments:
#         1. error message
#         2. exit code (default: 1)
#
# Example: test -n "$VAR" || die "VAR is not set!" 5
# If variable $VAR is not set, "VAR is not set!" will be printed on stderr
# and script in which it was invoked will exit with exit code equal to 5.
#
# Author: Aleksander Mistewicz <a.mistewicz@samsung.com>

die() {
    printf >&2 -- '%s\n' "$1"
    exit "${2:-1}"
}

test -z "${TSP_DIR}" || export TS_ONFINISH="${TSP_DIR}/scripts/log.sh"

WS="${HOME}/ws"
WS_WATCHER="${WS}/watcher"
WS_DOWNLOAD="${WS}/dwn"
WS_TEST="${WS}/img_test"
WS_TEST_REMOTE="${WS}/img_test_remote"
WS_PUBLISH="${WS}/publish"

DBNAME="results.db3"
DBPATH="${WS_PUBLISH}/${DBNAME}"
WWW_PUBLISH="${WS_PUBLISH}/current_status.html"

TMP_POLL="/tmp/tl-master-poll"
TMP_MASTER="/tmp/tl-master"
TMP_PWB="/tmp/tl-pwb"

test -d "$TMP_POLL" || mkdir "$TMP_POLL"
test -d "$TMP_MASTER" || mkdir "$TMP_MASTER"
test -d "$TMP_PWB" || mkdir "$TMP_PWB"

alias tspoll="TMPDIR=$TMP_POLL TS_SLOTS=1 tsp"
alias tsmaster="TMPDIR=$TMP_MASTER TS_SLOTS=100 tsp"
alias tspwb="TMPDIR=$TMP_PWB TS_SLOTS=1 tsp"

tsrun_target() {
    test -n "$1" || die "Missing argument: target"
    TMPDIR="/tmp/tl-runner-$1"
    test -d "$TMPDIR" || mkdir "$TMPDIR"
    shift
    TMPDIR="$TMPDIR" TS_SLOTS=1 tsp $@
}
