#!/bin/sh

# Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Author: Aleksander Mistewicz <a.mistewicz@samsung.com>

export TSP_DIR="$(CDPATH='' cd -- "$(dirname -- "$0")" && pwd -P)/.."

. "${TSP_DIR}/common.sh"

BUILD_NR="$1"
TARGET="$2"

test -n "${BUILD_NR}" || die "Missing argument: build nr"
test -n "$TARGET" || die "Missing argument: target"

WORKDIR_REMOTE="${WS_TEST_REMOTE}/${BUILD_NR}"
DWN_WORKDIR="${WS_DOWNLOAD}/${BUILD_NR}"


case "$TARGET" in
    *odroid*)
        BOOT_IMG="$(ls "${DWN_WORKDIR}"/tizen-common_*-boot-*.tar.gz)"
        USERSPACE_IMG="$(ls "${DWN_WORKDIR}"/tizen-common_*-wayland-*.tar.gz)"
        ;;
    *minnow*)
        USERSPACE_IMG="$(ls "${DWN_WORKDIR}"/tizen-common_*-wayland-*-sda.raw.bz2)"
        USERSPACE_IMG_BMAP="$(ls "${DWN_WORKDIR}"/tizen-common_*-wayland-*-sda.bmap)"
        ;;
esac

FAIL_CNT="$3"
test -n "${FAIL_CNT}" || FAIL_CNT=0

retrigger() {
    # Add job back to the queue
    echo "Retrigger... ($1)"
    echo "FAILED 1" > sysctl.result
    tsrun_target "${TARGET}" -L "RETRIGGERED_$(echo "$TARGET" | tr '[:lower:]' '[:upper:]')_PREPARE_FLASH_CONF" \
        sh "${TSP_DIR}/jobs/common_prep_flash_conf.sh" "$BUILD_NR" "${TARGET}" "$((FAIL_CNT + 1))"
    exit 0
}

if [ "$FAIL_CNT" -ge 2 ]; then
    # Trigger publish job
    tspwb -L PUBLISH sh "${TSP_DIR}/jobs/publish.sh" "$BUILD_NR" "$TARGET"
    exit 1
fi

# Create and clean required directories on remote machine (tl-runner)
ssh tl-runner "rm -rf \"${WORKDIR_REMOTE}\"; mkdir -p \"${WORKDIR_REMOTE}\"" || retrigger "ssh: remote ws cleanup failed"

# Copy required files
case "$TARGET" in
    *odroid*)
        scp "${USERSPACE_IMG}" "${BOOT_IMG}" tl-runner:"${WORKDIR_REMOTE}/" || retrigger "ssh: copy failed"
        ;;
    *minnow*)
        scp "${USERSPACE_IMG}" "${USERSPACE_IMG_BMAP}" tl-runner:"${WORKDIR_REMOTE}/" || retrigger "ssh: copy failed"
        ;;
esac


echo "start remote script"
ssh tl-runner "TARGET=${TARGET} FAIL_CNT=${FAIL_CNT} WORKDIR_REMOTE=${WORKDIR_REMOTE} timeout 10m sh -s --" \
    < "${TSP_DIR}/scripts/common_prep_flash_conf.sh" || retrigger "ssh: remote script execution failed"
echo "finish remote script"

# Copy the results
scp tl-runner:"${WORKDIR_REMOTE}/sysctl.result" .

{
    echo "RETRIGGER_CNT ${FAIL_CNT}"
    echo "Build nr: ${BUILD_NR}"
    echo "Date: $(date)"
} >> sysctl.result

# Check if they have run successfully, otherwise reschedule the job
if grep -q "Testing failed." sysctl.result
then
    retrigger "Testing failed."
fi

# Trigger publish job
tspwb -L PUBLISH sh "${TSP_DIR}/jobs/publish.sh" "$BUILD_NR" "$TARGET"
