#!/bin/sh

# Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Author: Aleksander Mistewicz <a.mistewicz@samsung.com>

export TSP_DIR="$(CDPATH='' cd -- "$(dirname -- "$0")" && pwd -P)/.."

. "${TSP_DIR}/common.sh"

test -n "$1" || die "Missing argument: build nr"

WORKDIR="${WS_TEST}/$1"
DWN_WORKDIR="${WS_DOWNLOAD}/$1"
TARGET="$2"

check_diff() {
    DIFF_FILE="$1"
    JOB_NR="$2"
    TARGET="$3"
    test -n "$1" || die "Missing argument: diff file"
    test -n "$2" || die "Missing argument: build nr"
    test -n "$3" || die "Missing argument: target"
    test -n "${TSP_DIR}" || die "Missing environment variable: TSP_DIR"
    if grep -q "identical" "${DIFF_FILE}"
    then
        echo "Image is unchanged in respect to snapshot"
        tspwb -L PUBLISH sh "${TSP_DIR}/jobs/publish.sh" "${JOB_NR}" "${TARGET}"
        return 1
    fi
}

test -n "$TARGET" || die "Missing argument: target"

DIFF_FILE="${DWN_WORKDIR}/diff-${TARGET}.report"

rm -rf "${WORKDIR}"
mkdir -p "${WORKDIR}"
cd "${WORKDIR}"
if check_diff "${DIFF_FILE}" "$1" "${TARGET}";
then
    echo "Add common_prep_flash_conf job to the $TARGET queue"
    tsrun_target "$TARGET" -L "$(echo "$TARGET" | tr '[:lower:]' '[:upper:]')_PREPARE_FLASH_CONF" \
        sh "${TSP_DIR}/jobs/common_prep_flash_conf.sh" "$1" "${TARGET}"
fi
