#!/bin/sh

# Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Author: Aleksander Mistewicz <a.mistewicz@samsung.com>

export TSP_DIR="$(CDPATH='' cd -- "$(dirname -- "$0")" && pwd -P)/.."

. "${TSP_DIR}/common.sh"

mkdir -p "${WS_WATCHER}"
cd "${WS_WATCHER}"
touch next_dwn
i=$(cat next_dwn)
test -n "$i" || i=1
if [ -f manual_urls ];
then
    sort -u modified_urls manual_urls > unique_dispatch
else
    cp modified_urls unique_dispatch
fi
while read -r url
do
    test -n "${url}" || continue
    echo "Processing: ${url}"
    if [ "$url" = "*latest*" ]
    then
        echo "Skipping symlink url"
        continue
    fi
    # kill currently running jobs for this url
    for i in $(tsmaster | awk -v URL="$url" '$2 ~ "running" && $0 ~ URL {print $1}'); do kill "$(tsmaster -p "$i")"; done
    for target in "minnow32" "minnow64" "odroid"
    do
        rm -rf "${WS_DOWNLOAD}/$i"
        mkdir -p "${WS_DOWNLOAD}/$i"
        cd "${WS_DOWNLOAD}/$i"
        # Download image for $target
        nr=$(tsmaster -L "DOWNLOAD_IMAGE_${target}" python "${TSP_DIR}/scripts/download_image.py" --log=INFO -t "${target}" "$url")
        nr=$(tsmaster -D "$nr" -L "IMAGE_TEST" \
            sh "${TSP_DIR}/jobs/img_test_common.sh" "$i" "$target")
        i=$((i+1))
    done
done < unique_dispatch
cd "${WS_WATCHER}"
echo "$i" > "next_dwn"
rm -f unique_dispatch modified_urls manual_urls
