#!/bin/sh

# Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Script run on the remote machine (tl-runner)
#
# Author: Aleksander Mistewicz <a.mistewicz@samsung.com>

# WORKDIR_REMOTE, TARGET and FAIL_CNT are given as environment variables

TESTLAB_MAJOR="/opt/testlab-major"

cd "${WORKDIR_REMOTE}" || exit
case "$TARGET" in
    *odroid*)
        BOOT_IMG="$(pwd)/$(ls tizen-common_*-boot-*.tar.gz)"
        USR_IMG="$(pwd)/$(ls tizen-common_*-wayland-*.tar.gz)"
        ;;
    *minnow*)
        USR_IMG="$(pwd)/$(ls tizen-common_*_common-*-sda.raw.bz2)"
        USR_IMG_BMAP="$(pwd)/$(ls tizen-common_*_common-*-sda.bmap)"
        ;;
esac

# Make sure that userspace image exists
if [ "${USR_IMG}" = "$(pwd)/" ]; then
    echo "Image not found." > sysctl.result
    exit 1
else
    # This info will be overwritten later if the tests run successfully
    echo "Testing failed." > sysctl.result
fi

# Lock resource
SDMUX="$(python "${TESTLAB_MAJOR}/tct/resource_locking.py" --retrylock "${TARGET}")"
if [ -z "${SDMUX}" ]; then
    echo "Failed to allocate SD MUX device." >> sysctl.result
    echo "FAILED 1" >> sysctl.result
    exit 1
fi

case "$TARGET" in
    *odroid*)
        "${TESTLAB_MAJOR}/tct/odroid_prepare_flash_conf.sh" "$SDMUX" "$USR_IMG" "$BOOT_IMG"
        ;;
    *minnow*)
        "${TESTLAB_MAJOR}/tct/minnow_prepare_flash_conf.sh" "$SDMUX" "$USR_IMG"
        ;;
esac

if grep -q "Testing failed." sysctl.result
then
    echo "FAILED 1" >> sysctl.result
    python "${TESTLAB_MAJOR}/tct/resource_locking.py" --unlockfailed "${SDMUX}"
else
    echo "FAILED 0" >> sysctl.result
    python "${TESTLAB_MAJOR}/tct/resource_locking.py" --unlock "${SDMUX}"
fi

echo "sdmux used: ${SDMUX}" >> sysctl.result

case "$TARGET" in
    *odroid*)
        rm -v "$USR_IMG" "$BOOT_IMG"
        ;;
    *minnow*)
        rm -v "$USR_IMG" "$USR_IMG_BMAP"
        ;;
esac
